MethodChannelGrowdeckPlaytimePlugin class

An implementation of GrowdeckPlaytimePluginPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

methodChannel → MethodChannel
The method channel used to interact with the native platform.
final

Static Methods

initialize({required String appId, required String userId, required String secretKey}) → Future<void>
isInitialized() → Future<bool>
show() → Future<void>